"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _columnsContainer = _interopRequireDefault(require("./columnsContainer"));

var _indexesContainer = _interopRequireDefault(require("./indexesContainer"));

var _webinySqlTable = require("webiny-sql-table");

var _sql = require("./sql");

class MySQLDriver extends _webinySqlTable.Driver {
  constructor(options = {}) {
    super();
    this.connection = null;
    options.connection && this.setConnection(options.connection);
  }

  getConnection() {
    return this.connection;
  }

  setConnection(connection) {
    this.connection = connection;
    return this;
  }

  getColumnsClass() {
    return _columnsContainer.default;
  }

  getIndexesClass() {
    return _indexesContainer.default;
  } // eslint-disable-next-line


  async create(table, options) {
    return (0, _sql.createTable)(table);
  } // eslint-disable-next-line


  async alter(table, options) {
    return (0, _sql.alterTable)(table);
  } // eslint-disable-next-line


  async drop(table, options) {
    return (0, _sql.dropTable)(table);
  } // eslint-disable-next-line


  async truncate(table, options) {
    return (0, _sql.truncateTable)(table);
  } // eslint-disable-next-line


  async sync(table, options) {
    const hasTable = await this.execute(`SHOW TABLES LIKE '${table.getName()}'`);

    if (hasTable.length) {
      // Table exist, we must alter the table.
      // const tableStructure = await this.execute(`DESCRIBE ${table.getName()}`);
      return "";
    } // Table does not exist, we can safely return SQL for new table creation create a new table.


    return this.create(table, options);
  }

  async execute(sql) {
    const connection = this.getConnection();

    if (connection) {
      return await connection.query(sql);
    }

    throw Error("MySQL connection not set.");
  }

}

var _default = MySQLDriver;
exports.default = _default;
//# sourceMappingURL=mysqlDriver.js.map